@@ -40,7 +40,6 @@ from magicgui.widgets._bases.widget import Widget
 from magicgui.widgets._bases import ButtonWidget, ValueWidget
 from macrokit import Expr, Head, Symbol, symbol
 
-
 from .keybinding import as_shortcut
 from .mgui_ext import (
     AbstractAction,
@@ -61,6 +60,7 @@ from ..utils import (
     argcount,
     is_instance_method,
     method_as_getter,
+    eval_attribute,
     thread_worker,
 )
 from ..widgets import Separator, FreeWidget
@@ -74,12 +74,15 @@ if TYPE_CHECKING:
 
 
 class PopUpMode(Enum):
+    """Define how to popup FunctionGui."""
+
     popup = "popup"
     first = "first"
     last = "last"
     above = "above"
     below = "below"
     dock = "dock"
+    dialog = "dialog"
     parentlast = "parentlast"
 
 
@@ -117,6 +120,7 @@ class ErrorMode(Enum):
         """Wrap function with the error handler."""
         handler = self.get_handler()
 
+        @functools_wraps(func)
         def wrapped_func(*args, **kwargs):
             try:
                 out = func(*args, **kwargs)
@@ -125,12 +129,6 @@ class ErrorMode(Enum):
                 out = e
             return out
 
-        wrapped_func.__annotations__ = func.__annotations__
-        # wrapped_func.__name__ = func.__name__  # this is not allowed!
-        wrapped_func.__qualname__ = func.__qualname__
-        wrapped_func.__doc__ = func.__doc__
-        wrapped_func.__module__ = func.__module__
-
         return wrapped_func
 
 
@@ -592,53 +590,12 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
         text = obj.__name__.replace("_", " ")
         widget = self._component_class(name=obj.__name__, text=text, gui_only=True)
 
-        # Wrap function to deal with errors in a right way.
-        func = self._error_mode.wrap_handler(obj, parent=self)
-
-        # Signature must be updated like this. Otherwise, already wrapped member function
-        # will have signature with "self".
-        obj_sig = inspect.signature(obj)
-        func.__signature__ = obj_sig
+        func = _create_gui_method(self, obj)
 
         # Prepare a button or action
         widget.tooltip = Tooltips(func).desc
         widget._doc = func.__doc__
 
-        # This block enables instance methods in "bind" or "choices" of ValueWidget.
-        all_params: list[inspect.Parameter] = []
-        for param in func.__signature__.parameters.values():
-            if isinstance(param.annotation, _AnnotatedAlias):
-                # TODO: after magicgui supports pydantic, something needs update here.
-                param = MagicParameter.from_parameter(param)
-
-            if isinstance(param, MagicParameter):
-                _param = MagicParameter(
-                    name=param.name,
-                    default=param.default,
-                    annotation=split_annotated_type(param.annotation)[0],
-                    gui_options=param.options.copy(),
-                )
-                _arg_bind = _param.options.get("bind", None)
-                _arg_choices = _param.options.get("choices", None)
-
-                # If bound method is a class method, use self.method(widget).
-                if is_instance_method(_arg_bind):
-                    _param.options["bind"] = method_as_getter(self, _arg_bind)
-
-                # If a MagicFiled is bound, bind the value of the connected widget.
-                elif isinstance(_arg_bind, MagicField):
-                    _param.options["bind"] = _arg_bind.as_remote_getter(self)
-
-                # If choices are provided by a class method, use self.method(widget).
-                if is_instance_method(_arg_choices):
-                    _param.options["choices"] = method_as_getter(self, _arg_choices)
-
-            else:
-                _param = param
-
-            all_params.append(_param)
-
-        func.__signature__ = func.__signature__.replace(parameters=all_params)
         # Get the number of parameters except for empty widgets.
         # With these lines, "bind" method of magicgui works inside magicclass.
         fgui_classes = callable_to_classes(func)
@@ -647,11 +604,6 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
         )
         nparams = argcount(func) - n_empty
 
-        if isinstance(func.__signature__, MagicMethodSignature):
-            func.__signature__.additional_options = getattr(
-                obj_sig, "additional_options", {}
-            )
-
         has_preview = get_additional_option(func, "preview", None) is not None
 
         if nparams == 0 and not has_preview:
@@ -684,19 +636,23 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
                 return out
 
         else:
-            _prep_func = _define_popup(self, obj, widget)
+            _prep_func = _define_popup(self, func, widget)
 
             def run_function():
                 mgui = _build_mgui(widget, func, self)
                 if mgui.call_count == 0 and len(mgui.called._slots) == 0:
                     _prep_func(mgui)
-                    if self._popup_mode not in (PopUpMode.popup, PopUpMode.dock):
+                    if self._popup_mode not in (
+                        PopUpMode.popup,
+                        PopUpMode.dock,
+                        PopUpMode.dialog,
+                    ):
                         mgui.label = ""
                         # to avoid name collision
                         mgui.name = f"mgui-{id(mgui._function)}"
                         mgui.margins = (0, 0, 0, 0)
                         title = Separator(
-                            orientation="horizontal", text=text, button=True
+                            orientation="horizontal", title=text, button=True
                         )
                         title.btn_text = "-"
                         # TODO: should remove mgui from self?
@@ -704,9 +660,9 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
                         mgui.insert(0, title)
 
                     if self._close_on_run and not mgui._auto_call:
-                        if self._popup_mode != PopUpMode.dock:
+                        if self._popup_mode not in (PopUpMode.dock, PopUpMode.dialog):
                             mgui.called.connect(mgui.hide)
-                        else:
+                        elif self._popup_mode == PopUpMode.dock:
                             # If FunctioGui is docked, we should close QDockWidget.
                             mgui.called.connect(lambda: mgui.parent.hide())
 
@@ -722,17 +678,19 @@ class MagicTemplate(metaclass=_MagicTemplateMeta):
                     else:
                         return None
 
-                if self._popup_mode != PopUpMode.dock:
+                if self._popup_mode not in (PopUpMode.dock, PopUpMode.dialog):
                     widget.mgui.show()
-                else:
+                elif self._popup_mode == PopUpMode.dock:
                     mgui.parent.show()  # show dock widget
+                else:
+                    mgui.exec_as_dialog()
 
                 return None
 
         widget.changed.connect(run_function)
 
         # If design is given, load the options.
-        widget.from_options(obj)
+        widget.from_options(func)
 
         # keybinding
         keybinding = get_additional_option(func, "keybinding", None)
@@ -925,6 +883,62 @@ def _get_widget_name(widget: Widget):
     return widget.name
 
 
+def _create_gui_method(self: BaseGui, obj: MethodType):
+    func_sig = inspect.signature(obj)
+    # Method type cannot set __signature__ attribute.
+    @functools_wraps(obj)
+    def func(*args, **kwargs):
+        return obj(*args, **kwargs)
+
+    func.__signature__ = func_sig
+
+    # This block enables instance methods in "bind" or "choices" of ValueWidget.
+    all_params: list[inspect.Parameter] = []
+    for param in func.__signature__.parameters.values():
+        if isinstance(param.annotation, _AnnotatedAlias):
+            param = MagicParameter.from_parameter(param)
+
+        if isinstance(param, MagicParameter):
+            _param = MagicParameter(
+                name=param.name,
+                default=param.default,
+                annotation=split_annotated_type(param.annotation)[0],
+                gui_options=param.options.copy(),
+            )
+            _arg_bind = _param.options.get("bind", None)
+            _arg_choices = _param.options.get("choices", None)
+
+            # If bound method is a class method, use self.method(widget).
+            if isinstance(_arg_bind, str):
+                _arg_bind = eval_attribute(type(self), _arg_bind)
+
+            if is_instance_method(_arg_bind):
+                _param.options["bind"] = method_as_getter(self, _arg_bind)
+
+            # If a MagicFiled is bound, bind the value of the connected widget.
+            elif isinstance(_arg_bind, MagicField):
+                _param.options["bind"] = _arg_bind.as_remote_getter(self)
+
+            # If choices are provided by a class method, use self.method(widget).
+            if isinstance(_arg_choices, str):
+                _arg_choices = eval_attribute(type(self), _arg_choices)
+
+            if is_instance_method(_arg_choices):
+                _param.options["choices"] = method_as_getter(self, _arg_choices)
+
+        else:
+            _param = param
+
+        all_params.append(_param)
+
+    func.__signature__ = func.__signature__.replace(parameters=all_params)
+    if isinstance(func.__signature__, MagicMethodSignature):
+        func.__signature__.additional_options = getattr(
+            func_sig, "additional_options", {}
+        )
+    return func
+
+
 def _build_mgui(widget_: Action | PushButtonPlus, func: Callable, parent: BaseGui):
     if widget_.mgui is not None:
         return widget_.mgui
@@ -934,6 +948,15 @@ def _build_mgui(widget_: Action | PushButtonPlus, func: Callable, parent: BaseGu
             opt = sig.additional_options
         else:
             opt = {}
+
+        # confirmation
+        conf = opt.get("confirm", None)
+        if conf is not None:
+            func = _implement_confirmation(func, parent, **conf)
+
+        # Wrap function to deal with errors in a right way.
+        func = parent._error_mode.wrap_handler(func, parent=parent)
+
         call_button = opt.get("call_button", None)
         layout = opt.get("layout", "vertical")
         labels = opt.get("labels", True)
@@ -1260,46 +1283,47 @@ def convert_attributes(cls: type[_T], hide: tuple[type, ...]) -> dict[str, Any]:
 
 def _define_popup(self: BaseGui, obj, widget: PushButtonPlus | Action):
     # deal with popup mode.
-    if self._popup_mode == PopUpMode.popup:
+    popup_mode = self._popup_mode
+    if popup_mode == PopUpMode.popup:
         # To be popped up correctly, window flags of FunctionGui should be
         # "windowFlags" and should appear at the center.
         def _prep(mgui: FunctionGui):
             mgui.native.setParent(self.native, mgui.native.windowFlags())
             move_to_screen_center(mgui.native)
 
-    elif self._popup_mode == PopUpMode.parentlast:
+    elif popup_mode == PopUpMode.parentlast:
 
         def _prep(mgui: FunctionGui):
             parent_self = self._search_parent_magicclass()
             parent_self.append(mgui)
 
-    elif self._popup_mode == PopUpMode.first:
+    elif popup_mode == PopUpMode.first:
 
         def _prep(mgui: FunctionGui):
             child_self = _child_that_has_widget(self, obj, widget)
             child_self.insert(0, mgui)
 
-    elif self._popup_mode == PopUpMode.last:
+    elif popup_mode == PopUpMode.last:
 
         def _prep(mgui: FunctionGui):
             child_self = _child_that_has_widget(self, obj, widget)
             child_self.append(mgui)
 
-    elif self._popup_mode == PopUpMode.above:
+    elif popup_mode == PopUpMode.above:
 
         def _prep(mgui: FunctionGui):
             child_self = _child_that_has_widget(self, obj, widget)
             i = _get_index(child_self, widget)
             child_self.insert(i, mgui)
 
-    elif self._popup_mode == PopUpMode.below:
+    elif popup_mode == PopUpMode.below:
 
         def _prep(mgui: FunctionGui):
             child_self = _child_that_has_widget(self, obj, widget)
             i = _get_index(child_self, widget)
             child_self.insert(i + 1, mgui)
 
-    elif self._popup_mode == PopUpMode.dock:
+    elif popup_mode == PopUpMode.dock:
         from .class_gui import MainWindowClassGui
 
         def _prep(mgui: FunctionGui):
@@ -1323,6 +1347,58 @@ def _define_popup(self: BaseGui, obj, widget: PushButtonPlus | Action):
                     mgui, name=_get_widget_name(widget), area="right"
                 )
 
+    elif popup_mode == PopUpMode.dialog:
+
+        def _prep(mgui: FunctionGui):
+            mgui.call_button.visible = False
+
     else:
-        raise RuntimeError
+        raise RuntimeError(popup_mode)
     return _prep
+
+
+def _implement_confirmation(
+    method: MethodType,
+    self: BaseGui,
+    text: str,
+    condition: Callable[[BaseGui], bool] | str,
+    callback: Callable[[str, BaseGui], None],
+):
+    """Implement confirmation callback to a method."""
+    sig = inspect.signature(method)
+
+    @wraps(method)
+    def _method(*args, **kwargs):
+        if self[method.__name__].running:
+            arguments = sig.bind(*args, **kwargs)
+            arguments.apply_defaults()
+            all_args = arguments.arguments
+            all_args.update(self=self)
+            need_confirmation = False
+            if isinstance(condition, str):
+                try:
+                    need_confirmation = eval(condition, {}, all_args)
+                except Exception as e:
+                    msg = e.args[0]
+                    e.args = (
+                        f"Exception happened on evaluating condition {condition!r}.\n"
+                        f"{type(e).__name__}: {msg}"
+                    )
+                    raise e
+            elif callable(condition):
+                need_confirmation = condition(self)
+            else:
+                warnings.warn(
+                    f"Condition {condition} should be callable or string but got type "
+                    f"{type(condition)}. No confirmation was executed.",
+                    UserWarning,
+                )
+            if need_confirmation:
+                callback(text.format(**all_args), self)
+
+        return method(*args, **kwargs)
+
+    if hasattr(method, "__signature__"):
+        _method.__signature__ = method.__signature__
+
+    return _method
