@@ -58,6 +58,7 @@ PopUpModeStr = Union[
     Literal["above"],
     Literal["below"],
     Literal["dock"],
+    Literal["dialog"],
     Literal["parentlast"],
 ]
 
@@ -102,7 +103,7 @@ def bound(obj):
         outtype = obj.__annotations__.get("return", Any)
     elif isinstance(obj, MagicField):
         outtype = obj.annotation or Any
-    elif isinstance(obj, type):
+    elif isinstance(obj, (type, str)):
         outtype = Any
     else:
         raise TypeError("'bound' can only convert callable, MagicField or type objects")
@@ -177,6 +178,56 @@ class Bound(metaclass=_BoundAlias):
         raise TypeError(f"Cannot subclass {cls.__module__}.Bound")
 
 
+class _ChoicesAlias(type):
+    """
+    This metaclass is necessary for ``mypy`` to reveal type.
+    """
+
+    @overload
+    def __getitem__(cls, value: Callable[_P, Iterable[_V]]) -> type[_V]:
+        ...
+
+    @overload
+    def __getitem__(cls, value: Iterable[_V]) -> type[_V]:
+        ...
+
+    @_tp_cache
+    def __getitem__(cls, value):
+        if callable(value):
+            outtype = value.__annotations__.get("return", Any)
+        elif hasattr(value, "__iter__"):
+            outtype = Any
+        else:
+            raise TypeError("'bound' can only convert callable or iterable objects.")
+        return Annotated[outtype, {"choices": value, "nullable": False}]
+
+
+class Choices(metaclass=_ChoicesAlias):
+    """
+    Make Annotated type from a method, such as:
+
+    .. code-block:: python
+
+        from magicclass import magicclass
+
+        @magicclass
+        class MyClass:
+            def func(self, v: Choices[(1, 2, 3)]):
+                ...
+
+    ``Choices[value]`` is identical to ``Annotated[Any, {"choices": value}]``.
+    """
+
+    def __new__(cls, *args):
+        raise TypeError(
+            "`Bound(...)` is deprecated since 0.5.21. Bound is now a generic alias instead "
+            "of a function. Please use `Bound[...]`."
+        )
+
+    def __init_subclass__(cls, *args, **kwargs):
+        raise TypeError(f"Cannot subclass {cls.__module__}.Bound")
+
+
 _T = TypeVar("_T", bound=type)
 
 
@@ -214,6 +265,21 @@ class Optional(metaclass=_OptionalAlias):
 
     Arguments annotated with ``Optional[int]`` will create a
     ``OptionalWidget`` with a ``SpinBox`` as an inner widget.
+
+    Examples
+    --------
+
+    from magicclass import magicclass, set_options
+    from magicclass.types import Optional
+
+    @magicclass
+    class A:
+        @set_options(a={"options": {"min": -1}})
+        def f(self, a: Optional[int]):
+            print(a)
+
+    ui = A()
+    ui.show()
     """
 
     def __new__(cls, *args, **kwargs):
@@ -284,26 +350,3 @@ class List(metaclass=_ListAlias):
 
     def __init_subclass__(cls, *args, **kwargs):
         raise TypeError(f"Cannot subclass {cls.__module__}.List.")
-
-
-"""
-Examples
---------
-
-from magicclass import magicclass, set_options
-from magicclass.types import Tuple, List, Optional
-@magicclass
-class A:
-    @set_options(a={"options": {"min": -1}})
-    def f(self, a: Tuple[int, int]):
-        print(a)
-    @set_options(a={"options": {"min": -1}})
-    def g(self, a: List[float]):
-        print(a)
-    @set_options(a={"options": {"min": -1}})
-    def h(self, a: Optional[int]):
-        print(a)
-ui = A()
-ui.show()
-
-"""
