@@ -1,10 +1,12 @@
-from .functions import (
+from ._functions import (
     iter_members,
     Tooltips,
     get_signature,
     argcount,
     is_instance_method,
     method_as_getter,
+    eval_attribute,
+    copy_info,
     show_tree,
     rst_to_html,
 )
@@ -19,5 +21,6 @@ from .qt import (
     screen_scale,
 )
 
+from ._click import click
 from .qtsignal import QtSignal
 from .qthreading import thread_worker, Timer
