@@ -412,6 +412,10 @@ class thread_worker:
 
         self._progress = progress
 
+    @property
+    def func(self) -> Callable[_P, _R1]:
+        return self._func
+
     @classmethod
     def set_default(cls, pbar_cls: Callable | str):
         """
@@ -446,6 +450,14 @@ class thread_worker:
         """True if bound function is a generator function."""
         return inspect.isgeneratorfunction(self._func)
 
+    @property
+    def __doc__(self) -> str:
+        return self.func.__doc__
+
+    @__doc__.setter
+    def __doc__(self, doc: str):
+        self.func.__doc__ = doc
+
     def _set_recorder(self, recorder: Callable[_P, Any]):
         """
         Set macro recorder function.
