@@ -1,8 +1,6 @@
 from __future__ import annotations
-from functools import wraps
 import inspect
-from typing import Callable, Iterable, Iterator, Union, TYPE_CHECKING, TypeVar, overload
-from typing_extensions import ParamSpec
+from typing import Callable, Iterable, Union, TYPE_CHECKING, TypeVar, overload
 import warnings
 from magicgui.widgets import FunctionGui
 
@@ -12,12 +10,9 @@ from .signature import upgrade_signature
 
 if TYPE_CHECKING:
     from ._gui import BaseGui
-    from ._gui.mgui_ext import Action
-    from magicgui.widgets._bases import ButtonWidget
 
 nStrings = Union[str, Iterable[str]]
 
-P = ParamSpec("P")
 R = TypeVar("R")
 T = TypeVar("T")
 F = TypeVar("F", bound=Callable)
@@ -102,7 +97,6 @@ def set_design(
     max_height: int = None,
     text: str = None,
     icon_path: str = None,
-    icon_size: tuple[int, int] = None,
     font_size: int = None,
     font_family: int = None,
     font_color: Color = None,
@@ -131,18 +125,11 @@ def set_design(
     icon_path : str, optional
         Path to icon file. ``min_width`` and ``min_height`` will be automatically set to the icon size
         if not given.
-    icon_size : tuple of two int, optional
-        Icon size.
     font_size : int, optional
         Font size of the text.
     visible : bool default is True
         Button visibility.
     """
-    if icon_size is not None:
-        if min_width is None:
-            min_width = icon_size[0]
-        if min_height is None:
-            min_height = icon_size[1]
 
     caller_options = locals()
     caller_options = {k: v for k, v in caller_options.items() if v is not None}
@@ -172,59 +159,6 @@ def set_design(
     return wrapper
 
 
-def click(
-    enables: nStrings = None,
-    disables: nStrings = None,
-    enabled: bool = True,
-    shows: nStrings = None,
-    hides: nStrings = None,
-    visible: bool = True,
-):
-    """
-    Set options of push buttons related to button clickability.
-
-    Parameters
-    ----------
-    enables : str or iterable of str, optional
-        Enables other button(s) in this list when clicked.
-    disables : str or iterable of str, optional
-        Disables other button(s) in this list when clicked.
-    enabled : bool, default is True
-        The initial clickability state of the button.
-    shows : str or iterable of str, optional
-        Make other button(s) in this list visible when clicked.
-    hides : str or iterable of str, optional
-        Make other button(s) in this list invisible when clicked.
-    visible: bool, default is True
-        The initial visibility of the button.
-    """
-    enables = _assert_iterable(enables)
-    disables = _assert_iterable(disables)
-    shows = _assert_iterable(shows)
-    hides = _assert_iterable(hides)
-
-    def wrapper(func):
-        @wraps(func)
-        def f(self, *args, **kwargs):
-            out = func(self, *args, **kwargs)
-            for button in _iter_widgets(self, enables):
-                button.enabled = True
-            for button in _iter_widgets(self, disables):
-                button.enabled = False
-            for button in _iter_widgets(self, shows):
-                button.visible = True
-            for button in _iter_widgets(self, hides):
-                button.visible = False
-
-            return out
-
-        caller_options = {"enabled": enabled, "visible": visible}
-        upgrade_signature(f, caller_options=caller_options)
-        return f
-
-    return wrapper
-
-
 def do_not_record(method: F) -> F:
     """Wrapped method will not be recorded in macro."""
     upgrade_signature(method, additional_options={"record": False})
@@ -256,12 +190,12 @@ class Canceled(RuntimeError):
     """Raised when a function is canceled"""
 
 
-# TODO: confirm is not exchangable with thread_worker
 @overload
 def confirm(
     *,
     text: str | None,
-    condition: Callable[P, bool] | str | None,
+    condition: Callable[..., bool] | str | None,
+    callback: Callable[[str, BaseGui], None] | None = None,
 ) -> Callable[[F], F]:
     ...
 
@@ -271,7 +205,8 @@ def confirm(
     f: F,
     *,
     text: str | None,
-    condition: Callable[P, bool] | str | None,
+    condition: Callable[..., bool] | str | None,
+    callback: Callable[[str, BaseGui], None] | None = None,
 ) -> F:
     ...
 
@@ -281,6 +216,7 @@ def confirm(
     *,
     text: str | None = None,
     condition: Callable[[BaseGui], bool] | str = None,
+    callback: Callable[[str, BaseGui], None] | None = None,
 ):
     """
     Confirm if it is OK to run function in GUI.
@@ -305,9 +241,15 @@ def confirm(
         function ``f(a, b)`` decorated by ``confirm(condition="a < b + 1")`` will
         evaluate ``a < b + 1`` to check if confirmation is needed. Always true by
         default.
+    callback : callable, optional
+        Callback function when confirmation is needed. Must take a ``str`` and a
+        ``BaseGui`` object as inputs. By default, message box will be shown. Useful
+        for testing.
     """
     if condition is None:
         condition = lambda x: True
+    if callback is None:
+        callback = _default_confirmation
 
     def _decorator(method: F) -> F:
         _name = method.__name__
@@ -321,47 +263,34 @@ def confirm(
             raise TypeError(
                 f"The first argument of 'confirm' must be a str but got {type(text)}."
             )
-
-        sig = inspect.signature(method)
-
-        @wraps(method)
-        def _method(self: BaseGui, *args, **kwargs):
-            if self[_name].running:
-                arguments = sig.bind(self, *args, **kwargs)
-                arguments.apply_defaults()
-                all_args = arguments.arguments
-                need_confirmation = False
-                if isinstance(condition, str):
-                    need_confirmation = eval(condition, {}, all_args)
-                elif callable(condition):
-                    need_confirmation = condition(self)
-                else:
-                    warnings.warn(
-                        f"Condition {condition} should be callable or string but got type "
-                        f"{type(condition)}. No confirmation was executed.",
-                        UserWarning,
-                    )
-                if need_confirmation:
-                    ok = show_messagebox(
-                        mode="question",
-                        title="Confirmation",
-                        text=_text.format(**all_args),
-                        parent=self.native,
-                    )
-                    if not ok:
-                        raise Canceled("Canceled")
-
-            return method(self, *args, **kwargs)
-
-        if hasattr(method, "__signature__"):
-            _method.__signature__ = method.__signature__
-        return _method
+        upgrade_signature(
+            method,
+            additional_options={
+                "confirm": {
+                    "text": _text,
+                    "condition": condition,
+                    "callback": callback,
+                }
+            },
+        )
+        return method
 
     if f is not None:
         return _decorator(f)
     return _decorator
 
 
+def _default_confirmation(text: str, gui: BaseGui):
+    ok = show_messagebox(
+        mode="question",
+        title="Confirmation",
+        text=text,
+        parent=gui.native,
+    )
+    if not ok:
+        raise Canceled("Canceled")
+
+
 def nogui(method: F) -> F:
     """Wrapped method will not be converted into a widget."""
     upgrade_signature(method, additional_options={"gui": False})
@@ -450,35 +379,3 @@ def mark_preview(function: Callable, text: str = "Preview") -> Callable[[F], F]:
         return preview
 
     return _wrapper
-
-
-def _assert_iterable(obj):
-    if obj is None:
-        obj = []
-    elif isinstance(obj, str) or callable(obj):
-        obj = [obj]
-    return obj
-
-
-def _iter_widgets(
-    self: BaseGui, descriptors: Iterable[list[str]] | Iterable[Callable]
-) -> Iterator[ButtonWidget | Action]:
-    for f in descriptors:
-        if callable(f):
-            # A.B.func -> B.func, if self is an object of A.
-            f = f.__qualname__.split(self.__class__.__name__)[1][1:]
-
-        if isinstance(f, str):
-            *clsnames, funcname = f.split(".")
-            # search for parent class that match the description.
-            ins = self
-            for a in clsnames:
-                if a != "":
-                    ins = getattr(ins, a)
-                else:
-                    ins = ins.__magicclass_parent__
-
-            button = ins[funcname]
-        else:
-            raise TypeError(f"Unexpected type in click decorator: {type(f)}")
-        yield button
